@@ -8,7 +8,7 @@ import numpy as np
 import torch
 import torch.nn as nn
 
-from utils_.downloads import attempt_download
+from yolov5_utils.downloads import attempt_download
 
 
 class Sum(nn.Module):
